@@ -11,7 +11,7 @@ writeFindFn2xls <- function(x,
 ## 1.  x not null?
 ##
   if(nrow(x) < 1) {
-    cat('No matches;  nothing written.\'n')
+    cat('No matches;  nothing written.\n')
     return(invisible(''))
   }
 ##
@@ -49,7 +49,7 @@ writeFindFn2xls <- function(x,
           WXo <- try(WriteXLS::WriteXLS(c('sum2', 'x2.', 'cl'),
                  ExcelFileName=file.,
                  SheetNames=c('PackageSum2', 'findFn', 'call') ))
-          if(class(WXo)!='try-error')return(invisible(file.))
+          if(!inherits(WXo, 'try-error'))return(invisible(file.))
         }
       }
 ##
@@ -58,17 +58,17 @@ writeFindFn2xls <- function(x,
      if(requireNamespace('RODBC', quietly=TRUE)){
         RO <- TRUE
         xlsFile <- try(RODBC::odbcConnectExcel(file., readOnly=FALSE))
-        if(class(xlsFile)!='try-error'){
-          on.exit(RODBC::odbcClose(xlsFile))
+        if(!inherits(xlsFile, 'try-error')){
+          on.exit(try(RODBC::odbcClose(xlsFile))) 
 #   Create the sheets
           sum2. <- try(RODBC::sqlSave(xlsFile, sum2, tablename='PackageSum2'))
-          if(class(sum2.)!='try-error'){
+          if(!inherits(sum2., 'try-error')){
             x. <- try(RODBC::sqlSave(xlsFile, as.data.frame(x2),
                                    tablename='findFn'))
 #
-            if(class(x.)!='try-error'){
+            if(!inherits(x., 'try-error')){
               cl. <- try(RODBC::sqlSave(xlsFile, cl, tablename='call'))
-              if(class(cl.)!='try=error')return(invisible(file.))
+              if(!inherits(cl., 'try=error'))return(invisible(file.))
             }
           }
         }
